package com.quickblox.quickblox_sdk.chat;

import androidx.test.internal.runner.junit4.AndroidJUnit4ClassRunner;

import com.quickblox.core.exception.QBResponseException;
import com.quickblox.quickblox_sdk.BaseTest;
import com.quickblox.quickblox_sdk.chat.utils.ChatDialogUtils;
import com.quickblox.quickblox_sdk.chat.utils.CustomDataUtils;

import org.junit.After;
import org.junit.Before;
import org.junit.Test;
import org.junit.runner.RunWith;

import java.util.HashMap;
import java.util.Map;
import java.util.concurrent.CountDownLatch;
import java.util.concurrent.TimeUnit;

import static androidx.test.platform.app.InstrumentationRegistry.getInstrumentation;

/**
 * Created by Injoit on 2022-04-07.
 * Copyright © 2022 Quickblox. All rights reserved.
 */

@RunWith(AndroidJUnit4ClassRunner.class)
public class CreateDialogWithCustomDataTest extends BaseTest {

    @Before
    public void init() {
        super.initContext();
        super.initCredentials();

        try {
            new CountDownLatch(1).await(5, TimeUnit.SECONDS);
            login();
        } catch (QBResponseException | InterruptedException e) {
            e.printStackTrace();
            throw new RuntimeException("Error init() method: " + e.getMessage());
        }
    }

    @After
    public void release() {
        try {
            logout();
        } catch (QBResponseException e) {
            e.printStackTrace();
            throw new RuntimeException("Error release() method: " + e.getMessage());
        }
    }

    @Test
    public void createDialogWithCorrectCustomData() throws InterruptedException, QBResponseException {
        final CountDownLatch downLatch = new CountDownLatch(1);

        Map<String, Object> uploadedCustomData = CustomDataUtils.buildCorrectCustomData();
        int uploadedCustomDataSize = uploadedCustomData.size();

        Map<String, Object> dialogData = ChatDialogUtils.buildDialog();
        dialogData.put("customData", uploadedCustomData);

        getInstrumentation().runOnMainSync(() -> new ChatModule().createDialog(dialogData, new ResultImpl() {
            @Override
            public void success(Object value) {
                Map<?, ?> customDataMap = (Map<?, ?>) ((Map<?, ?>) value).get("customData");

                int downloadedCustomDataSize = customDataMap.size();

                assertEquals(uploadedCustomDataSize, downloadedCustomDataSize);

                downLatch.countDown();
            }
        }));

        downLatch.await(10, TimeUnit.SECONDS);

        assertEquals(0, downLatch.getCount());
    }

    @Test(expected = RuntimeException.class)
    public void createDialogWithEmptyCustomData() {
        Map<String, Object> dialogData = ChatDialogUtils.buildDialog();
        dialogData.put("customData", new HashMap<String, Object>());

        getInstrumentation().runOnMainSync(() -> new ChatModule().createDialog(dialogData, new ResultImpl() {
            @Override
            public void success(Object o) {
                fail("expected: error, actual: resolve");
            }
        }));

        fail("expected: error, actual: correct end of test");
    }

    @Test
    public void createDialogWithEmptyCustomDataButHasClassName() throws InterruptedException {
        final CountDownLatch downLatch = new CountDownLatch(1);

        Map<String, Object> dialogData = ChatDialogUtils.buildDialog();
        dialogData.put("customData", CustomDataUtils.buildEmptyCustomDataButHasClassName());

        getInstrumentation().runOnMainSync(() -> new ChatModule().createDialog(dialogData, new ResultImpl() {
            @Override
            public void success(Object o) {
                assertNotNull(o);
                downLatch.countDown();
            }
        }));

        downLatch.await(10, TimeUnit.SECONDS);

        assertEquals(0, downLatch.getCount());
    }

    @Test(expected = RuntimeException.class)
    public void createDialogWithWrongCustomData() {
        Map<String, Object> dialogData = ChatDialogUtils.buildDialog();
        dialogData.put("customData", CustomDataUtils.buildWrongCustomData());

        getInstrumentation().runOnMainSync(() -> new ChatModule().createDialog(dialogData, new ResultImpl() {
            @Override
            public void success(Object o) {
                fail("expected: error, actual: resolve");
            }
        }));

        fail("expected: error, actual: correct end of test");
    }

    @Test(expected = RuntimeException.class)
    public void createDialogWith_3correct_1Wrong_CustomData() {
        Map<String, Object> dialogData = ChatDialogUtils.buildDialog();
        dialogData.put("customData", CustomDataUtils.build_3correct_1WrongCustomData());

        getInstrumentation().runOnMainSync(() -> new ChatModule().createDialog(dialogData, new ResultImpl() {
            @Override
            public void success(Object o) {
                fail("expected: error, actual: resolve");
            }
        }));

        fail("expected: error, actual: correct end of test");
    }
}