import 'package:flutter_test/flutter_test.dart';
import 'package:integration_test/integration_test.dart';
import 'package:quickblox_sdk/chat/constants.dart';
import 'package:quickblox_sdk/models/qb_dialog.dart';
import 'package:quickblox_sdk/quickblox_sdk.dart';

import '../base/credentials.dart';
import 'utils/dialog_utils.dart';

void main() {
  String? _dialogId;

  IntegrationTestWidgetsFlutterBinding.ensureInitialized();

  setUpAll(() async {
    await Credentials.init();
  });

  setUp(() async {
    await Future.delayed(const Duration(seconds: 5), null);

    await Credentials.loginToRest();
    await Credentials.loginToChat();

    QBDialog? dialog = await QB.chat.createDialog(DialogUtils.buildOccupants(),
        dialogName: "Updated ${DialogUtils.buildDialogName()}",
        dialogType: QBChatDialogTypes.GROUP_CHAT);

    _dialogId = dialog!.id;
  });

  tearDown(() async {
    await Credentials.logoutChat();
    await Credentials.logoutRest();
  });

  test("send to new group dialog without join", () async {
    await QB.chat.sendMessage(_dialogId!);
  });

  test("send to exist group dialog without join", () async {
    await QB.chat.sendMessage(Credentials.DIALOG_ID);
  });
}
