import 'package:flutter/services.dart';
import 'package:flutter_test/flutter_test.dart';
import 'package:integration_test/integration_test.dart';
import 'package:quickblox_sdk/quickblox_sdk.dart';

void main() {
  IntegrationTestWidgetsFlutterBinding.ensureInitialized();

  setUp(() async {
    await Future.delayed(const Duration(seconds: 3), null);
  });

  test("set correct time interval", () async {
    await QB.rtcConfig.setDialingTimeInterval(10);
  });

  test("set correct and get correct time interval", () async {
    int expectedInterval = 25;

    await QB.rtcConfig.setDialingTimeInterval(expectedInterval);
    int? actualInterval = await QB.rtcConfig.getDialingTimeInterval();

    expect(actualInterval == expectedInterval, true);
  });

  test("get default time interval", () async {
    int? interval = await QB.rtcConfig.getDialingTimeInterval();
    expect(interval! > 0, true);
  });

  test("set wrong time interval", () async {
    try {
      await QB.rtcConfig.setDialingTimeInterval(-1);
      fail("Expected: Exception, actual: No thrown Exception");
    } on PlatformException catch (e) {
      expect(e, e);
    }
  });

  test("set wrong and get default time interval", () async {
    try {
      await QB.rtcConfig.setDialingTimeInterval(-1);
      fail("Expected: Exception, actual: No thrown Exception");
    } on PlatformException catch (e) {
      expect(e, e);
    }

    int? interval = await QB.rtcConfig.getDialingTimeInterval();
    expect(interval! > 0, true);
  });
}
