import 'package:quickblox_sdk/mappers/qb_messages_counter_mapper.dart';
import 'package:quickblox_sdk/models/qb_messages_counter.dart';
import 'package:test/test.dart';

void main() {
  test("pass null, get null", () {
    QBMessagesCounter? counter = QBMessagesCounterMapper.mapToQBMessageCounter(null);
    expect(counter == null, true);
  });

  test("pass empty map, get null", () {
    QBMessagesCounter? counter = QBMessagesCounterMapper.mapToQBMessageCounter({});
    expect(counter == null, true);
  });

  test("pass wrong map, get null", () {
    Map<String, Object> map = {};
    map["wrong1"] = 8;
    map["wrong2"] = "-1";
    map["wrong3"] = 878.00;
    QBMessagesCounter? counter = QBMessagesCounterMapper.mapToQBMessageCounter({});
    expect(counter == null, true);
  });

  test("pass wrong map, get QBMessageCounter with total, without dialogs", () {
    Map<String, Object> map = {};
    map["totalCount"] = 88;

    QBMessagesCounter? counter = QBMessagesCounterMapper.mapToQBMessageCounter(map);

    expect(counter?.total, 88);
    expect(counter?.dialogs, null);
  });

  test("pass wrong map, get QBMessageCounter without total, with dialogs", () {
    Map<String, int> dialogMap1 = {};
    dialogMap1["dialog_id_1"] = 1;

    Map<String, int> dialogMap2 = {};
    dialogMap2["dialog_id_2"] = 2;

    Map<String, int> dialogMap3 = {};
    dialogMap3["dialog_id_3"] = 3;

    Map<String, int> dialogMap4 = {};
    dialogMap4["dialog_id_3"] = 4;

    Map<String, Object> map = {};
    map["dialogsCount"] = [dialogMap1, dialogMap2, dialogMap3, dialogMap4];

    QBMessagesCounter? counter = QBMessagesCounterMapper.mapToQBMessageCounter(map);

    int actualDialogsCounter = 0;
    counter?.dialogs?.forEach((element) {
      actualDialogsCounter += element.values.single;
    });

    expect(counter?.total, null);
    expect(counter?.dialogs?.length, 4);
    expect(actualDialogsCounter == 10, true);
  });

  test("pass correct map, get QBMessageCounter with total, with dialogs", () {
    Map<String, int> dialogMap1 = {};
    dialogMap1["dialog_id_1"] = 1;

    Map<String, int> dialogMap2 = {};
    dialogMap2["dialog_id_2"] = 2;

    Map<String, int> dialogMap3 = {};
    dialogMap3["dialog_id_3"] = 3;

    Map<String, int> dialogMap4 = {};
    dialogMap4["dialog_id_3"] = 4;

    Map<String, Object> map = {};
    map["totalCount"] = 88;
    map["dialogsCount"] = [dialogMap1, dialogMap2, dialogMap3, dialogMap4];

    QBMessagesCounter? counter = QBMessagesCounterMapper.mapToQBMessageCounter(map);

    int actualDialogsCounter = 0;
    counter?.dialogs?.forEach((element) {
      actualDialogsCounter += element.values.single;
    });

    expect(counter?.total, 88);
    expect(counter?.dialogs?.length, 4);
    expect(actualDialogsCounter == 10, true);
  });
}
